@@ -111,10 +111,10 @@ def get_spark(scale=0, queue=None):
     if scale in [1, 2, 3, 4]:
         spark = (
             SparkSession.builder.config("spark.app.name", app_name)
-            .config("spark.driver.memory", f"{scale*8}g")
-            .config("spark.executor.memory", f"{scale*3}g")
-            .config("spark.executor.instances", f"{scale*8}")
-            .config("spark.driver.maxResultSize", f"{scale*4}g")
+            .config("spark.driver.memory", f"{scale * 8}g")
+            .config("spark.executor.memory", f"{scale * 3}g")
+            .config("spark.executor.instances", f"{scale * 8}")
+            .config("spark.driver.maxResultSize", f"{scale * 4}g")
             .config("spark.rpc.message.maxSize", "1024")
             .config("spark.yarn.queue", queue)
             .config("spark.ui.enabled", "false")
@@ -316,7 +316,7 @@ def send_email(subject, text, send_from, send_to, attachment=None):
     from pydatafabric.vault_utils import get_secrets
 
     c = get_secrets(mount_point="datafabric", path="mail")
-    host, port = c["smtp_host"], c["smtp_port"]
+    host, port, ehlo = c["smtp_host"], c["smtp_port"], c["local_hostname"]
     msg = MIMEMultipart()
     msg["From"] = send_from
     msg["To"] = send_to
@@ -329,7 +329,7 @@ def send_email(subject, text, send_from, send_to, attachment=None):
         part.add_header("Content-Disposition", f"attachment; filename={subject}.txt")
         msg.attach(part)
 
-    with smtplib.SMTP(host, port) as smtp:
+    with smtplib.SMTP(host=host, port=port, local_hostname=ehlo) as smtp:
         return smtp.sendmail(send_from, send_to.split(","), msg.as_string())
 
 
